import unittest
from pyriddle.riddle import riddle_factory


class TestRiddleFactory(unittest.TestCase):
    def setUp(self):
        self.data = {
            "What gets wetter as it dries?": ["A towel"],
            "I’m tall when I’m young and short when I’m old. What am I?": ["A candle"],
            "What has keys but can't open locks?": ["A piano"]
        }
        self.get_riddle, self.get_riddles = riddle_factory(self.data)

    def test_get_riddle(self):
        # Testing that get_riddle returns a dictionary with a question and answer
        riddle = self.get_riddle()
        self.assertIsInstance(riddle, dict)
        self.assertIn('question', riddle)
        self.assertIn('answer', riddle)
        self.assertIn(riddle['question'], self.data)
        self.assertIn(riddle['answer'], self.data[riddle['question']])

    def test_get_riddles_single(self):
        # Test fetching a single riddle via get_riddles
        riddles = self.get_riddles(1)
        self.assertEqual(len(riddles), 1)
        self.assertIsInstance(riddles[0], dict)

    def test_get_riddles_multiple(self):
        # Test fetching multiple riddles
        count = 2
        riddles = self.get_riddles(count)
        self.assertEqual(len(riddles), count)
        for riddle in riddles:
            self.assertIsInstance(riddle, dict)
            self.assertIn('question', riddle)
            self.assertIn('answer', riddle)
            self.assertIn(riddle['question'], self.data)
            self.assertIn(riddle['answer'], self.data[riddle['question']])

    def test_get_riddles_exceeds(self):
        # Test that a ValueError is raised when requesting more riddles than are available
        with self.assertRaises(ValueError):
            self.get_riddles(len(self.data) + 1)

    def test_cache_functionality(self):
        # Test to ensure that the cache gets used correctly
        first_call_riddle = self.get_riddle()
        second_call_riddle = self.get_riddle()
        self.assertNotEqual(first_call_riddle, second_call_riddle, "Cache should provide different riddles on subsequent calls until reset")

        # Verify that after exhausting cache, we get a repeated riddle or new one without error
        self.get_riddles(len(self.data))  # should repopulate the cache
        no_error_occurred = True
        try:
            self.get_riddles(len(self.data))
        except ValueError:
            no_error_occurred = False
        self.assertTrue(no_error_occurred, "Should not raise an error even after cache is exhausted and repopulated")

if __name__ == '__main__':
    unittest.main()



data = {
  'Almost everyone needs it, asks for it, gives it. But almost nobody takes it.': [
    'advice'
  ],
  'What goes up but never comes down?': [
    'age'
  ],
  'Die without me, never thank me. Walk right through me, never feel me. Always watching, never speaking. Always lurking, never seen.': [
    'air'
  ],
  'I cost no money to use, or conscious effort to take part of. And as far as you can see, there is nothing to me. But without me, you are dead.': [
    'air'
  ],
  'Today he is there to trip you up. And he will torture you tomorrow. Yet he is also there to ease the pain, when you are lost in grief and sorrow.': [
    'alcohol'
  ],
  'Come up and let us go. Go down and here we stay.': [
    'anchor'
  ],
  "What do you throw out to use and take in when you're done?": [
    'anchor'
  ],
  "I'm very tempting, so its said, I have a shiny coat of red, and my flesh is white beneath. I smell so sweet, taste good to eat, and help to guard your teeth.": [
    'apple'
  ],
  'I fly through the air on small feathered wings, seeking out life and destroying all things.': [
    'arrow'
  ],
  "I have many feathers to help me fly. I have a body and head, but I'm not alive. It is your strength which determines how far I go. You can hold me in your hand, but I'm never thrown.": [
    'arrow'
  ],
  "I can be moved. I can be rolled. But nothing will I hold. I'm red and I'm blue, and I can be other colors too. Having no head, though similar in shape. I have no eyes - yet move all over the place.": [
    'ball'
  ],
  "A time when they're green. A time when they're brown. But both of these times, cause me to frown. But just in between, for a very short while. They're perfect and yellow. And cause me to smile.": [
    'bananas'
  ],
  'My first is in blood and also in battle. My second is in acorn, oak, and apple. My third and fourth are both the same. In the center of sorrow and twice in refrain. My fifth starts eternity ending here. My last is the first of last, Oh Dear.': [
    'barrel'
  ],
  'I sleep by day, I fly by night. I have no feathers to aid my flight.': [
    'bat'
  ],
  'When I’m metal or wood, I help you get home. When I’m flesh and I’m blood, In the darkness I roam.': [
    'bat'
  ],
  "I am the yellow hem of the sea's blue skirt.": [
    'beach'
  ],
  'In the night a mountain, in the morning a meadow.': [
    'bed'
  ],
  'What is it that has four legs, one head, and a foot?': [
    'bed'
  ],
  'A warrior amongst the flowers, he bears a thrusting sword. He uses it whenever he must, to defend his golden hoard.': [
    'bee'
  ],
  'Thousands lay up gold within this house. But no man made it. Spears past counting guard this house, but no man wards it.': [
    'beehive'
  ],
  'Round as a button, deep as a well. If you want me to talk, you must first pull my tail.': [
    'bell'
  ],
  'You heart it speak, for it has a hard tongue. But it cannot breathe, for it has not a lung.': [
    'bell'
  ],
  "I am a fire's best friend. When fat, my body fills with wind. When pushed to thin, through my nose I blow. Then you can watch the embers glow.": [
    'bellows'
  ],
  'You get many of me, but never enough. After the last one, your life soon will snuff. You may have one of me but one day a year, When the last one is gone, your life disappears.': [
    'birthday'
  ],
  "I am seen in the water. If seen in the sky, I am in the rainbow, a jay's feather, and lapis lazuli.": [
    'blue'
  ],
  "My life is often a volume of grief, your help is needed to turn a new leaf. Stiff is my spine and my body is pale. But I'm always ready to tell a tale.": [
    'book'
  ],
  'Turns us on our backs, and open up our stomachs. You will be the wisest of men though at start a lummox.': [
    'books'
  ],
  "I heard of a wonder, of words moth-eaten. That is a strange thing, I thought, weird. That a man's song be swallowed by a worm. His blinded sentences, his bedside stand-by rustled in the night - and the robber-guest. Not one wit the wiser. For the words he had mumbled.": [
    'bookworm'
  ],
  'Two brothers we are, great burdens we bear. All day we are bitterly pressed. Yet this I will say, we are full all the day, and empty when go to rest.': [
    'boots'
  ],
  'I have a neck but no head. I have a body but no arm. I have a bottom but no leg.': [
    'bottle'
  ],
  'As light as a feather, but you can’t hold it for ten minutes.': [
    'breath'
  ],
  "Hard to catch, easy to hold. Can't be seen, unless it's cold.": [
    'breath'
  ],
  'I am free for the taking. Through all of your life, though given but once at birth. I am less than nothing in weight, but will fell the strongest of you if held.': [
    'breath'
  ],
  "I'm light as a feather, yet the strongest man can't hold me for more than 5 minutes. ": [
    'breath'
  ],
  "To cross the water I'm the way, for water I'm above. I touch it not and, truth to say, I neither swim nor move.": [
    'bridge'
  ],
  'All about the house, with his lady he dances, yet he always works, and never romances.': [
    'broom'
  ],
  "I have a hundred legs, but cannot stand. I have a long neck, but no head. I cannot see. I'm neat and tidy as can be.": [
    'broom'
  ],
  "A muttered rumble was heard from the pen, and I, in my walking stopped to look in. What was this I saw? A massive beast, hoofed, and jawed. With spikes upon its mighty brow, I watched as he struck the turf and prowled. And yet for all of his magnificence, he couldn't get out of that wooden fence.": [
    'bull'
  ],
  'What lies in a tunnel of darkness. That can only attack when pulled back?': [
    'bullet'
  ],
  "Flat as a leaf, round as a ring. Has two eyes, can't see a thing.": [
    'button'
  ],
  'No matter how little or how much you use me, you change me every month.': [
    'calendar'
  ],
  'I have one eye. See near and far. I hold the moments you treasure and the things that make you weep.': [
    'camera'
  ],
  'Always wax, yet always wane: I melt, succumbed to the flame. Lighting darkness, with fate unblest, I soon devolve to shapeless mess.': [
    'candle'
  ],
  'My life can be measured in hours. I serve by being devoured. Thin, I am quick. Fat, I am slow. Wind is my foe.': [
    'candle'
  ],
  'What has 13 hearts but none beat?': [
    'cards'
  ],
  'What kind of pet always stays on the floor?': [
    'carpet'
  ],
  "Halo of water, tongue of wood. Skin of stone, long I've stood. My fingers short reach to the sky. Inside my heart men live and die.": [
    'castle'
  ],
  "Stealthy as a shadow in the dead of night, cunning but affectionate if given a bite. Never owned but often loved. At my sport considered cruel, but that's because you never know me at all.": [
    'cat'
  ],
  'Though desert men once called me God, today men call me mad. For I wag my tail when I am angry. And growl when I am glad.': [
    'cat'
  ],
  "I'm not really more than holes tied to more holes. I'm strong as good steel, though not as stiff as a pole.": [
    'chain'
  ],
  'I have legs but walk not, a strong back but work not. Two good arms but reach not. A seat but sit and tarry not.': [
    'chair'
  ],
  "What's black when you get it, red when you use it, and white when you're all through with it?": [
    'charcoal'
  ],
  "Not born, but from a Mother's body drawn. I hang until half of me is gone. I sleep in a cave until I grow old. Then valued for my hardened gold.": [
    'cheese'
  ],
  'I wear a red robe, with staff in hand, and a stone in my throat.': [
    'cherry'
  ],
  'A slow, solemn square-dance of warriors feinting. One by one they fall, warriors fainting, thirty-two on sixty-four.': [
    'chess'
  ],
  'What is it that given one, you’ll have either two or none?': [
    'choice'
  ],
  "I have a face, yet no senses. But I don't really care, because time is of the essence.": [
    'clock'
  ],
  'This thing runs but cannot walk, sometimes sings but never talks. Lacks arms, has hands; lacks a head but has a face.': [
    'clock'
  ],
  'I fly, yet I have no wings. I cry, yet I have no eyes. Darkness follows me. Lower light I never see.': [
    'cloud'
  ],
  "Black we are and much admired. Many seek us if they are tired. We tire the horse, and comfort man, and turn White when we've fulfilled your plan.": [
    'coal'
  ],
  'What’s black in the morning, red in the afternoon, and white at night?': [
    'coal'
  ],
  'A little pool with two layers of wall around it. One white and soft and the other dark and hard. Amidst a light brown grassy lawn with an outline of a green grass.': [
    'coconut'
  ],
  "The man who made it didn't need it. The man who bought it didn't use it. The man who used it didn't want it.": [
    'coffin'
  ],
  'The one who makes it, sells it. The one who buys it, never uses it. The one that uses it never knows that he’s using it. ': [
    'coffin'
  ],
  'I am two-faced but bear only one. I have no legs but travel widely. Men spill much blood over me. Kings leave their imprint on me. I have greatest power when given away, yet lust for me keeps me locked away.': [
    'coin'
  ],
  'What can you catch but not throw?': [
    'cold'
  ],
  'Metal or bone I may be, many teeth I have and always bared. Yet my bite harms no one. And ladies delight in my touch.': [
    'comb'
  ],
  'I am so simple that I can only point. Yet I guide men all over the world.': [
    'compass'
  ],
  'You throw away the outside and cook the inside. Then you eat the outside and throw away the inside. What did you eat?': [
    'corn'
  ],
  'Whoever makes it, tells it not. Whoever takes it, knows it not. Whoever knows it, wants it not': [
    'counterfeit'
  ],
  'The more of it there is, the less you see.': [
    'darkness'
  ],
  'Five hundred begins it, five hundred ends it. Five in the middle is seen. First of all figures, the first of all letters. Take up their stations between. Join all together, and then you will bring before you the name of an eminent king.': [
    'david'
  ],
  "Some try to hide, some try to cheat. But time will show, we always will meet. Try as you might, to guess my name. I promise you'll know, when you I do claim.": [
    'death'
  ],
  'What begins and has no end? What is the ending of all that begins?': [
    'death'
  ],
  'What is put on a table, cut, but never eaten?': [
    'deck'
  ],
  'I dig out tiny caves and store gold and silver in them. I also build bridges of silver and make crowns of gold. They are the smallest you could imagine. Sooner or later everybody needs my help. Yet many people are afraid to let me help them.': [
    'dentist'
  ],
  "You will find me with four legs, but no hair. People ride me for hours, but I don't go anywhere without needing to be tugged. Jerked or turned on, I always manage to be ready for work.": [
    'desk'
  ],
  'A tiny bead, like fragile glass, strung along a cord of grass.': [
    'dew'
  ],
  'What has six faces and twenty-one eyes?': [
    'die'
  ],
  'What wears a coat in the winter and pants in the summer?': [
    'dog'
  ],
  'Hands she has but does not hold. Teeth she has but does not bite. Feet she has but they are cold. Eyes she has but without sight.': [
    'doll'
  ],
  "I don't think or eat or slumber. Or move around or fear thunder. Just like you I look the same but I can't harm you or be your bane.": [
    'doll'
  ],
  'What kind of nut is empty at the center and has no shell.': [
    'doughnut'
  ],
  "My first is in window but not in pane. My second's in road but not in lane. My third is in oval but not in round. My fourth is in hearing but not in sound. My whole is known as a sign of peace. And from noah's ark won quick release.": [
    'dove'
  ],
  'A word I know, six letters it contains. Subtract just one and twelve remains.': [
    'dozens'
  ],
  'This is in a realm of true and in a realm false, but you experience me as you turn and toss.': [
    'dream'
  ],
  'Although my cow is dead, I still beat her\x85 What a racket she makes.': [
    'drum'
  ],
  "People are hired to get rid of me. I'm often hiding under your bed. In time I'll always return you see. Bite me and you're surely dead.": [
    'dust'
  ],
  "I am the third from a sparkle bright, I thrive throughout the day and night. Deep in the path of a cows white drink. I've had thousands of millions of years to think. But one of my creatures is killing me. And so the question I ask to thee, is ": [
    'earth'
  ],
  'You heard me before, yet you hear me again, then I die. Until you call me again.': [
    'echo'
  ],
  'A box without hinges, lock or key, yet golden treasure lies within. ': [
    'egg'
  ],
  'In marble halls as white as milk, lined with a skin as soft as silk. Within a fountain crystal-clear. A golden apple doth appear. No doors there are to this stronghold, yet thieves break in and steal the gold.': [
    'egg'
  ],
  'What has to be broken before it can be used?': [
    'egg'
  ],
  'I drift forever with the current down these long canals they’ve made, Tame, yet wild, I run elusive Multitasking to your aid. Before I came, the world was darker, colder, sometimes, rougher, true. But though I might make living easy, I’m good at killing people too.': [
    'electricity'
  ],
  'Face with a tree, skin like the sea. A great beast I am. Yet vermin frightens me.': [
    'elephant'
  ],
  "What word starts with 'E', ends with 'E', but only has one letter? It is not the letter 'E'.": [
    'envelope'
  ],
  "A hole in a pole, though I fill a hole in white. I'm used more by the day, and less by the night.": [
    'eye'
  ],
  'What is pronounced like one letter, written with three letters. And belongs to all animals?': [
    'eye'
  ],
  'Two horses, swiftest traveling, harnessed in a pair, and grazing ever in places. Distant from them.': [
    'eyes'
  ],
  'When set loose I fly away. Never so cursed as when I go astray.': [
    'fart'
  ],
  "It's in your hand though you can not feel it. Only you and time can reveal it.": [
    'fate'
  ],
  'I make you weak at the worst of all times. I keep you safe, I keep you fine. I make your hands sweat. And your heart grow cold. I visit the weak, but seldom the bold.': [
    'fear'
  ],
  'I am the outstretched fingers that seize and hold the wind. Wisdom flows from me in other hands. Upon me are sweet dreams dreamt, my merest touch brings laughter.': [
    'feather'
  ],
  'I know a word of letters three. Add two, and fewer there will be!': [
    'few'
  ],
  'Long and think, red within, with a nail at the end.': [
    'finger'
  ],
  'As destructive as life, As healing as death; An institutioner of strife, Just as prone to bless. It is all that is good, Yet with an evil trend; As it was the beginning of things, It can also be the end.': [
    'fire'
  ],
  'Feed me and I live, give me drink and I die. ': [
    'fire'
  ],
  'Give it food and it will live, give it water and it will die.': [
    'fire'
  ],
  'I am always hungry, I must always be fed. The finger I lick will soon turn red.': [
    'fire'
  ],
  'Screaming, soaring seeking sky. Flowers of fire flying high. Eastern art from ancient time. Name me now and solve this rhyme.': [
    'firework'
  ],
  'Alive without breath, As cold as death, Clad in mail never clinking, Never thirsty, ever drinking': [
    'fish'
  ],
  'I march before armies, a thousand salute me. My fall can bring victory, but no one would shoot me. The wind is my lover, one-legged am I. Name me and see me at home in the sky.': [
    'flag'
  ],
  'Up on high I wave away but not a word can I say.': [
    'flag'
  ],
  'When they are caught, they are thrown away. When they escape, you itch all day.': [
    'fleas'
  ],
  "A thousand colored folds stretch toward the sky. Atop a tender strand, rising from the land, until killed by maiden's hand. Perhaps a token of love, perhaps to say goodbye.": [
    'flower'
  ],
  'Who spends the day at the window, goes to the table for meals. And hides at night?': [
    'fly'
  ],
  'My second is performed by my first, and it is thought a thief by the marks of my whole might be caught.': [
    'footstep'
  ],
  "I bubble and laugh and spit water in your face. I am no lady, and I don't wear lace.": [
    'fountain'
  ],
  'I have four legs but no tail. Usually I am heard only at night.': [
    'frog'
  ],
  'Goes over all the hills and hollows. Bites hard, but never swallows.': [
    'frost'
  ],
  'My first is in fish but no in snail. My second is in rabbit but no in tail. My third is in up but not in down. My fourth is in tiara but not in crown. My fifth is in tree you plainly see. My whole a food for you and me.': [
    'fruit'
  ],
  'My first master has four legs, my second master has two. My first I serve in life, my second I serve in death. Tough I am, yet soft beside. Against ladies cheeks I often reside.': [
    'fur'
  ],
  'Born of earth, but with none of its strength. Molded by flame, but with none of its power. Shaped': [
    'glass'
  ],
  'Without a bridle, or a saddle, across a thing I ride a-straddle. And those I ride, by help of me, though almost blind, are made to see.': [
    'glasses'
  ],
  'They have not flesh, nor feathers, nor scales, nor bone. Yet they have fingers and thumbs of their own.': [
    'gloves'
  ],
  'What do you fill with empty hands?': [
    'gloves'
  ],
  'What I am filled, I can point the way. When I am empty. Nothing moves me. I have two skins. One without and one within.': [
    'gloves'
  ],
  'I drive men mad for love of me. Easily beaten, never free.': [
    'gold'
  ],
  'The sun bakes them, the hand breaks them, the foot treads on them, and the mouth tastes them.': [
    'grapes'
  ],
  'The sharp slim blade, that cuts the wind.': [
    'grass'
  ],
  'So cold, damp and dark this place. To stay you would refrain, yet those who occupy this place do never complain.': [
    'grave'
  ],
  'There is one word that stands the test of time and holds fast to the center of everything. Though everyone will try at least once in their life to move around this word, but in fact, unknowingly, they use it every moment of the day. Young or old, awake or in sleep, human or animal, this word stands fast. It belongs to everyone, to all living things, but no one can master it. The word is?': [
    'gravity'
  ],
  'They can be harbored, but few hold water. You can nurse them, but only by holding them against someone else. You can carry them, but not with your arms. You can bury them, but not in the earth.': [
    'grudge'
  ],
  "Long and slinky like a trout, never sings till it's guts come out.": [
    'gun'
  ],
  'I have one, you have one. If you remove the first letter, a bit remains. If you remove the second, bit still remains. If you remove the third, it still remains.': [
    'habit'
  ],
  'Grows from the ground, bushes and grass, leaves of yellow, red and brow, unruly plants, get the axe, trim the hedge back down.': [
    'hair'
  ],
  'What is that over the head and under the hat?': [
    'hair'
  ],
  "Two in a whole and four in a pair. And six in a trio you see. And eight's a quartet but what you must get. Is the name that fits just one of me?": [
    'half'
  ],
  'How far will a blind dog walk into a forest?': [
    'halfway'
  ],
  'They are many and one, they wave and they drum, Used to cover a state, they go with you everywhere.': [
    'hands'
  ],
  'What do you use to hoe a row, slay a foe, and wring with woe?': [
    'hands'
  ],
  "Inside a burning house, this thing is best to make. And best to make it quickly, before the fire's too much to take.": [
    'haste'
  ],
  'You can tumble in it, roll in it, burn it, animal eat it. Used to cover floors, still used beyond stall doors. Freshens whatever it is placed on. Absorbs whatever is poured into it.': [
    'hay'
  ],
  'A red drum which sounds without being touched, and grows silent, when it is touched.': [
    'heart'
  ],
  "I'm the source of all emotion, but I'm caged in a white prison.": [
    'heart'
  ],
  'If you break me, I do not stop working. If you touch me, I may be snared. If you lose me, nothing will matter.': [
    'heart'
  ],
  'It cannot be seen, it weighs nothing, but when put into a barrel, it makes it lighter. ': [
    'hole'
  ],
  'What can you put in a barrel to make it lighter?': [
    'hole'
  ],
  'What gets bigger the more you take away from it?': [
    'hole'
  ],
  'When you stop and look, you can always see me. If you try to touch, you cannot feel me. I cannot move, but as you near me, I will move away from you.': [
    'horizon'
  ],
  'What always goes to bed with his shoes on?': [
    'horse'
  ],
  'Two bodies have I, though both joined in one. The more still I stand, the quicker I run.': [
    'hourglass'
  ],
  "A precious stone, as clear as diamond. Seek it out while the sun's near the horizon. Though you can walk on water with its power, try to keep it, and it'll vanish in an hour.": [
    'ice'
  ],
  'Power enough to smash ships and crush roofs. Yet it still must fear the sun.': [
    'ice'
  ],
  'Lighter than what I am made of, More of me is hidden Than is seen.': [
    'iceberg'
  ],
  'Glittering points that downward thrust. Sparkling spears that never rust.': [
    'icicle'
  ],
  'What word has kst in the middle, in the beginning, and at the end?': [
    'inkstand'
  ],
  "Ripped from my mother's womb. Beaten and burned, I become a blood thirsty killer.": [
    'iron'
  ],
  'What goes in the water red, and comes out black?': [
    'iron'
  ],
  'I can be cracked, I can be made. I can be told, I can be played.': [
    'joke'
  ],
  'I cut through evil like a double edged sword, and chaos flees at my approach. Balance I single-handedly upraise, through battles fought with heart and mind, instead of with my gaze.': [
    'justice'
  ],
  'I turn around once. What is out will not get in. I turn around again. What is in will not get out.': [
    'key'
  ],
  'What force and strength cannot get through. I, with a gentle touch, can do. Many in the street would stand. Were I not a friend at hand.': [
    'key'
  ],
  'What goes through a door but never goes in. And never comes out?': [
    'keyhole'
  ],
  'Of no use to one, Bliss to two. Men lie for it. The baby’s right,': [
    'kiss'
  ],
  'I love to dance and twist and prance. I shake my tail, as away I sail. Wingless I fly into the sky.': [
    'kite'
  ],
  'Iron roof, glass walls, burns and burns and never falls.': [
    'lantern'
  ],
  'I am the red tongue of the earth, that buries cities.': [
    'lava'
  ],
  "They're up near the sky, on something very tall. Sometimes they die, only then do they fall.": [
    'leaves'
  ],
  'Walk on the living, they don’t even mumble. Walk on the dead, they mutter and grumble': [
    'leaves'
  ],
  'I do not breathe, but I run and jump. I do not eat, but I swim and stretch. I do not drink, but I sleep and stand. I do not think, but I grow and play. I do not see, but you see me everyday.': [
    'leg'
  ],
  'What building has the most stories?': [
    'library'
  ],
  "I'm sometimes white and always wrong. I can break a heart and hurt the strong. I can build love or tear it down. I can make a smile or bring a frown.": [
    'lie'
  ],
  'What an fill a room but takes up no space?': [
    'light'
  ],
  'What goes in the water black and comes out red?': [
    'lobster'
  ],
  "A dagger thrust at my own heart, dictates the way I'm swayed. Left I stand, and right I yield, to the twisting of the blade.": [
    'lock'
  ],
  'In your fire you hear me scream, creaking and whining, yet I am dead before you lay me in your hearth.': [
    'log'
  ],
  'What can touch someone once and last them a life time?': [
    'love'
  ],
  'I have rivers without water. Forests without trees. Mountains without rocks. Towns without houses.': [
    'map'
  ],
  'Tool of thief, toy of queen. Always used to be unseen. Sign of joy, sign of sorrow. Giving all likeness borrowed.': [
    'mask'
  ],
  'Take one out and scratch my head, I am now black but once was red.': [
    'match'
  ],
  'What can bring back the dead. Make us cry, make us laugh, make us young. Born in an instant yet lasts a life time?': [
    'memory'
  ],
  "I'm a god. I'm a planet. I measure heat.": [
    'mercury'
  ],
  'You can spin, wheel and twist. But this thing can turn without moving.': [
    'milk'
  ],
  'Something wholly unreal, yet seems real to I. Think my friend, tell me where does it lie?': [
    'mind'
  ],
  'I look at you, you look at me, I raise my right, you raise your left.': [
    'mirror'
  ],
  "If you drop me I'm sure to crack. But give me a smile and I'll always smile back.": [
    'mirror'
  ],
  "Look into my face and I'm everybody. Scratch my back and I'm nobody.": [
    'mirror'
  ],
  'When there is fire in me then I am still cold. When I own your true love’s face then you will not see me. To all things I give no more than I am given. In time I may have all things, and yet I can keep nothing. ': [
    'mirror'
  ],
  'A hill full, a hole full, yet you cannot catch a bowl full.': [
    'mist'
  ],
  'What goes further the slower it goes?': [
    'money'
  ],
  'Always old, sometimes new. Never sad, sometimes blue. Never empty, sometimes full. Never pushes, always pulls.': [
    'moon'
  ],
  'I am the hole in the night, the ever watchful eye. I return in a cycle, to enlighten the sky.': [
    'moon'
  ],
  "I'm white, I'm round, but not always around. Sometimes you see me, sometimes you don't.": [
    'moon'
  ],
  'It comes only before, it comes only after. Rises only in darkness, but rises only in light. It is always the same, but is yet always different.': [
    'moon'
  ],
  'My love, when I gaze on thy beautiful face. Careering along, yet always in place, the thought has often come into my mind. If I ever shall see thy glorious behind.': [
    'moon'
  ],
  'Pregnant every time you see her, yet she never will give birth.': [
    'moon'
  ],
  'Scythe of darkness, Shadow’s light. Guiding eye of thirteenth sight.': [
    'moon'
  ],
  'What has roots as nobody sees, is taller than trees. Up, up it goes, and yet never grows?': [
    'mountain'
  ],
  'What kind of room has no windows or doors?': [
    'mushroom'
  ],
  'At the sound of me, one may dream or stamp their feet, At the sound of me, one may laugh or sometimes weep.': [
    'music'
  ],
  'Who works when he plays and plays when he works?': [
    'musician'
  ],
  'I hide but my head is outside.': [
    'nail'
  ],
  'What is it that was given to you, belongs only to you. And yet your friends use it more than you do?': [
    'name'
  ],
  'An iron horse with a flaxen tail. The faster the horse runs, the shorter his tail becomes.': [
    'needle'
  ],
  'What has a single eye but cannot see?': [
    'needle'
  ],
  'What is long and slim, works in light. Has but one eye, and an awful bite?': [
    'needle'
  ],
  'A house of wood in a hidden place. Built without nails or glue. High above the earthen ground. It holds pale gems of blue.': [
    'nest'
  ],
  'Hold the tail, while I fish for you.': [
    'net'
  ],
  'I can be written, I can be spoken, I can be exposed, I can be broken.': [
    'news'
  ],
  "Sometimes I am loud. And viewed with distaste. Poke out my 'eye', then I'm on the front of your face.": [
    'noise'
  ],
  'What word is the same written forward, backward and upside down?': [
    'noon'
  ],
  'Gets rid of bad ones, short and tall. Tightens when used, one size fits all.': [
    'noose'
  ],
  'I can run but not walk. Wherever I go, thought follows close behind.': [
    'nose'
  ],
  'Two little holes in the side of a hill. Just as you come to the cherry-red mill.': [
    'nose'
  ],
  "It is greater than God and more evil than the devil. The poor have it, the rich need it, and if you eat it you'll die.": [
    'nothing'
  ],
  'What does man love more than life, fear more than death or mortal strife. What the poor have, the rich require, and what contented men desire. What the miser spends, and the spendthrift saves. And all men carry to their graves.': [
    'nothing'
  ],
  'A man went to the hardware store to buy items for his house. 1 would cost $.25. 12 would cost $.50. 122 would cost $.75. When he left the store he had spent $.75, what did he buy?': [
    'numbers'
  ],
  'A little house full of meat, no door to go in and eat.': [
    'nut'
  ],
  'I am the fountain from which no one can drink. For many I am considered a necessary link. Like gold to all I am sought for, but my continued death brings wealth for all to want more.': [
    'oil'
  ],
  "Take off my skin, I won't cry, but you will.": [
    'onion'
  ],
  'You use a knife to slice my head. And weep beside me when I am dead.': [
    'onion'
  ],
  'Gold in a leather bag, swinging on a tree, money after honey in its time. Ills of a scurvy crew cured by the sea, reason in its season but no rhyme.': [
    'orange'
  ],
  'What asks but never answers?': [
    'owl'
  ],
  "It holds most knowledge that has ever been said. But is not the brain, is not the head. To feathers and their masters, it's both bane and boon\x85One empty, and one full.": [
    'paper'
  ],
  'Half-way up the hill, I see you at last, lying beneath me with your sounds and sights. A city in the twilight, dim and vast, with smoking roofs, soft bells, and gleaming lights.': [
    'past'
  ],
  'The eight of us move forth and back. To protect our king from the foes attack.': [
    'pawns'
  ],
  'A seed am I, three letters make my name. Take away two and I still sound the same.': [
    'pea'
  ],
  "The strangest creature you'll ever find has two eyes in front and a hundred behind.": [
    'peacock'
  ],
  'A house with two occupants, sometimes one, rarely three. Break the walls, eat the boarders, then throw away me.': [
    'peanut'
  ],
  "Lovely and round, I shine with pale light, grown in the darkness, a lady's delight.": [
    'pearl'
  ],
  "I am the tool, for inspiring many. Buy me in the store, for not much more than a penny. Don't overuse me, or my usefulness will go.": [
    'pen'
  ],
  'I usually wear a yellow coat. I usually have a dark head. I make marks wherever I go.': [
    'pencil'
  ],
  'What has a head, a tail, is brown, and has no legs?': [
    'penny'
  ],
  'A woman shoots her husband, then holds him under water for five minutes. Finally, she hangs him. Five minutes later they enjoy a wonderful dinner together. How can this be?': [
    'photo'
  ],
  'I am a box that holds keys without locks, yet they can unlock your soul. ': [
    'piano'
  ],
  'My first is twice in apple but not once in tart. My second is in liver but not in heart. My third is in giant and also in ghost. Whole I’m best when I am roast.': [
    'pig'
  ],
  'What loses its head in the morning and gets it back at night?': [
    'pillow'
  ],
  'What makes a loud noise when changing its jacket, becomes larger but weighs less?': [
    'popcorn'
  ],
  'A skin have I, more eyes than one. I can be very nice when I am done.': [
    'potato'
  ],
  'What can be swallowed, But can also swallow you?': [
    'pride'
  ],
  'He has married many women but has never married.': [
    'priest'
  ],
  'I cannot be other than what I am, until the man who made me dies. Power and glory will fall to me finally. Only when he last closes his eyes.': [
    'prince'
  ],
  'Three little letters. A paradox to some. The worse that it is, the better it becomes.': [
    'pun'
  ],
  'Different lights do make me strange, thus into different sizes I will change.': [
    'pupil'
  ],
  'Only two backbones and thousands of ribs.': [
    'railroad'
  ],
  'I have split the one into five. I am the circle that few will spy. I am the path that breaks and gives. I am the bow no man may bend.': [
    'rainbow'
  ],
  'Break it and it is better, immediately set and harder to break again.': [
    'record'
  ],
  'You can see nothing else, When you look in my face, I will look you in the eye, And I will never lie.': [
    'reflection'
  ],
  'You saw me where I never was and where I could not be. And yet within that very place, my face you often see. ': [
    'reflection'
  ],
  'What can be heard and caught but never seen?': [
    'remark'
  ],
  "I am never quite what I appear to be. Straight-forward I seem, but it's only skin deep. For mystery most often lies beneath my simple speech. Sharpen your wits, open your eyes, look beyond my exteriors, read me backwards, forwards, upside down. Think and answer the question...": [
    'riddle'
  ],
  "To unravel me you need a simple key, no key that was made by locksmith's hand. But a key that only I will understand.": [
    'riddle'
  ],
  'It has no top or bottom, but it can hold flesh, bones, and blood all at the same time.': [
    'ring'
  ],
  'What always runs but never walks, often murmurs, never talks, has a bed but never sleeps, has a mouth but never eats?': [
    'river'
  ],
  'I run through hills. I veer around mountains. I leap over rivers. And crawl through the forests. Step out your door to find me.': [
    'road'
  ],
  "Snake coiled round and round. Snake deep below the ground. Snake that's never had a head. Snake that binds but not with dread.": [
    'rope'
  ],
  "Ten men's strength, ten men's length. Ten men can't break it, yet a young boy walks off with it.": [
    'rope'
  ],
  'What can burn the eyes, sting the mouth, yet be consumed?': [
    'salt'
  ],
  'I build up castles. I tear down mountains. I make some men blind. I help others to see.': [
    'sand'
  ],
  'One by one we fall from heaven down into the depths of past, And our world is ever upturned so that yet some time we’ll last.': [
    'sand'
  ],
  'What measures out time. Until in time all is smashed to it?': [
    'sand'
  ],
  'I bind it and it walks. I loose it and it stops.': [
    'sandal'
  ],
  'My teeth are sharp, my back is straight, to cut things up it is my fate.': [
    'saw'
  ],
  "I open wide and tight I shut, Sharp am I and paper-cut fingers too, so do take care, I'm good and bad, so best beware.": [
    'scissors'
  ],
  "If you have it, you want to share it. If you share it, you don't have it.": [
    'secret'
  ],
  "By Moon or by Sun, I shall be found. Yet I am undone, if there's no light around.": [
    'shadow'
  ],
  'Each morning I appear to lie at your feet, all day I follow no matter how fast you run. Yet I nearly perish in the midday sun.': [
    'shadow'
  ],
  'I crawl on the earth. And rise on a pillar.': [
    'shadow'
  ],
  'Only one color, but not one size. Stuck at the bottom, yet easily flies. Present in sun, but not in rain. Doing no harm, and feeling no pain.': [
    'shadow'
  ],
  "Tall in the morning, short at noon, gone at night. But I'll be back soon.": [
    'shadow'
  ],
  'Of these things - I have two. One for me - and one for you. And when you ask about the price, I simply smile and nod twice.': [
    'sharing'
  ],
  'Weight in my belly, Trees on my back, I travel fast in my place, but feet is a feature I lack': [
    'ship'
  ],
  'Whilst I was engaged in sitting. I spied the dead carrying the living': [
    'ship'
  ],
  'What has a neck and no head, two arms but no hands?': [
    'shirt'
  ],
  'Iron on a mammal. Mammal on your feet.': [
    'shoe'
  ],
  'Runs over fields and woods all day. Under the bed at night sits not alone, With long tongue hanging out, Resting at your feet until we go for a walk': [
    'shoe'
  ],
  'What runs around all day. Then lies under the bed. With its tongue hanging out?': [
    'shoe'
  ],
  'In buckles or lace, they help set the pace. The farther you go, the thinner they grow.': [
    'shoes'
  ],
  'What five-letter word becomes shorter when you add two more letters?': [
    'short'
  ],
  "What is round as a dishpan, deep as a tub, and still the oceans couldn't fill it up?": [
    'sieve'
  ],
  'What is so fragile that saying its name breaks it?': [
    'silence'
  ],
  "My first is in some but not in all. My second is into but not in tall. My third in little but no in big. My fourth in port but not in pig. My whole is made in nature's way. For clothing, rugs used every day.": [
    'silk'
  ],
  "A beggar's brother went out to sea and drowned. But the man who drowned had no brother. Who was the beggar to the man who drowned?": [
    'sister'
  ],
  "Double my number, I'm less than a score. Half of my number is less than four. Add one to my double when bakers are near. Days of the week are still greater, I fear.": [
    'six'
  ],
  'I am whole but incomplete. I have no eyes, yet I see. You can see, and see right through me. My largest part is one fourth of what I once was.': [
    'skeleton'
  ],
  'Twigs and spheres and poles and plates. Join and bind to reason make.': [
    'skeleton'
  ],
  'When liquid splashes me, none seeps through. When I am moved a lot, liquid I spew. When I am hit, color I change. And color, I come in quite a range. What I cover is very complex, and I am very easy to flex.': [
    'skin'
  ],
  'I weaken all men for hours each day. I show you strange visions while you are away. I take you by night, by day take you back. None suffer to have me, but do from my lack.': [
    'sleep'
  ],
  'A mile from end to end, yet as close to as a friend. A precious commodity, freely given. Seen on the dead and on the living. Found on the rich, poor, short and tall, but shared among children most of all. ': [
    'smile'
  ],
  'A house full, a yard full, a chimney full, no one can get a spoonful.': [
    'smoke'
  ],
  'If a man carried my burden, he would break his back. I am not rich, but leave silver in my track.': [
    'snail'
  ],
  'Who is he that runs without a leg. And his house on his back?': [
    'snail'
  ],
  'I can sizzle like bacon, I am made with an egg. I have plenty of backbone, but lack a good leg. I peel layers like onions, but still remain whole. I can be long, like a flagpole, yet fit in a hole.': [
    'snake'
  ],
  "As beautiful as the setting sun, as delicate as the morning dew. An angel's dusting from the stars. That can turn the Earth into a frosted moon.": [
    'snow'
  ],
  'High born, my touch is gentle. Purest white is my lace. Silence is my kingdom. Green is the color of my death.': [
    'snow'
  ],
  'White bird, featherless, flying out of paradise. Flying over sea and land. Dying in my hand.': [
    'snow'
  ],
  'I saw a man in white, he looked quite a sight. He was not old, but he stood in the cold. And when he felt the sun, he started to run. Who could he be? Please answer me.': [
    'snowman'
  ],
  "They made me a mouth, but didn't give me breath. Water gives me life, but the sun brings me death.": [
    'snowman'
  ],
  'You use it between your head and your toes, the more it works the thinner it grows.': [
    'soap'
  ],
  'I cannot be felt, seen or touched. Yet I can be found in everybody. My existence is always in debate. Yet I have my own style of music.': [
    'soul'
  ],
  'What surrounds the world, yet dwells within a thimble?': [
    'space'
  ],
  'A horrid monster hides from the day, with many legs and many eyes. With silver chains it catches prey. And eats it all before it dies. Yet in every cottage does it stay. And every castle beneath the sky.': [
    'spider'
  ],
  'I move without wings, Between silken string, I leave as you find, My substance behind.': [
    'spider'
  ],
  'I went to the woods and got it, when i got it didn’t want it, looked for it, couldn’t find it so I took it home.': [
    'splinter'
  ],
  "I'm full of holes, yet I'm full of water.": [
    'sponge'
  ],
  'We travel much, yet prisoners are, and close confined to boot. Yet with any horse, we will keep the pace, and will always go on foot.': [
    'spurs'
  ],
  'A nut cracker up in a tree.': [
    'squirrel'
  ],
  'As a whole, I am both safe and secure. Behead me, I become a place of meeting. Behead me again, I am the partner of ready. Restore me, I become the domain of beasts.': [
    'stable'
  ],
  'What has wings, but can not fly. Is enclosed, but can outside also lie. Can open itself up, or close itself away. Is the place of kings and queens and doggerel of every means. What is it upon which I stand? Which can lead us to different lands.': [
    'stage'
  ],
  "Upon me you can tread, though softly under cover. And I will take you places, that you have yet to discover. I'm high, and I'm low, though flat in the middle. And though a joy to the children, adults think of me little.": [
    'stairs'
  ],
  'What goes around the world and stays in a corner?': [
    'stamp'
  ],
  'With pointed fangs it sits in wait. With piercing force it doles out fate, over bloodless victims proclaiming its might. Eternally joining in a single bite.': [
    'stapler'
  ],
  'At night I come without being fetched. By day I am lost without being stolen.': [
    'stars'
  ],
  'We are all around, yet to us you are half blind. Sunlight makes us invisible, and difficult to find.': [
    'stars'
  ],
  'The more you take, the more you leave behind.': [
    'steps'
  ],
  'Four of us are in your field, But our differences keep us at yield, First, a one that is no fool, Though he resembles a gardener’s tool, Next, one difficult to split in two, And a girl once had one as big as her shoe, Then, to the mind, one’s a lovely bonder, And truancy makes it grow fonder, Last, a stem connecting dots of three': [
    'suits'
  ],
  'Inside a great blue castle lives a shy young maid. She blushes in the morning and comes not out at night.': [
    'sun'
  ],
  'My children are near and far. No matter that I know where they are. The gift I give them make their day. But if I were gone they would wander away.': [
    'sun'
  ],
  'What goes through the door without pinching itself? What sits on the stove without burning itself? What sits on the table and is not ashamed?': [
    'sun'
  ],
  'I appear in the morning. But am always there. You can never see me. Though I am everywhere. By night I am gone, though I sometimes never was. Nothing can defeat me. But I am easily gone.': [
    'sunlight'
  ],
  "Sleeping during the day, I hide away. Watchful through the night, I open at dawn's light. But only for the briefest time, do I shine. And then I hide away. And sleep through the day.": [
    'sunrise'
  ],
  'A dragons tooth in a mortals hand, I kill, I maim, I divide the land.': [
    'sword'
  ],
  'With sharp edged wit and pointed poise. It can settle disputes without making a noise.': [
    'sword'
  ],
  'He has one and a person has two. A citizen has three. And a human being has four. A personality has five. And an inhabitant of earth has six.': [
    'syllable'
  ],
  "Late afternoons I often bathe. I'll soak in water piping hot. My essence goes through. My see through clothes. Used up am I - I've gone to pot.": [
    'teabag'
  ],
  "What starts with a 'T', ends with a 'T', and has T in it?": [
    'teapot'
  ],
  'Soldiers line up spaced with pride. Two long rows lined side by side. One sole unit can decide, if the rows will unite or divide.': [
    'teeth'
  ],
  'Thirty white horses on a red hill, First they champ, Then they stamp, Then they stand still.': [
    'teeth'
  ],
  'You must keep this thing. Its loss will affect your brothers. For once yours is lost, it will soon be lost by others.': [
    'temper'
  ],
  'What is often returned, but never borrowed/': [
    'thanks'
  ],
  "What can't you see, hear or feel, until its too late. What shadows love, and shopkeepers hate?": [
    'thief'
  ],
  'An open ended barrel, it is shaped like a hive. It is filled with the flesh, and the flesh is alive.': [
    'thimble'
  ],
  'He stands beside the road. In a purple cap at tattered green cloak. Those who touch him, curse him.': [
    'thistle'
  ],
  "I walked and walked and at last I got it. I didn't want it. So I stopped and looked for it. When I found it, I threw it away.": [
    'thorn'
  ],
  'Soft and fragile is my skin, I get my growth in mud. I’m dangerous as much as pretty, for if not careful, I draw blood.': [
    'thorn'
  ],
  'Used left or right, I get to travel over cobblestone or gravel. Used up, I vie for sweet success, used down, I cause men great duress.': [
    'thumb'
  ],
  'Fatherless and motherless. Born without sin, roared when it came into the world. And never spoke again.': [
    'thunder'
  ],
  'When the day after tomorrow is yesterday. Today will be as far from Wednesday. As today was from Wednesday. When the day before yesterday was tomorrow. What is the day after this day?': [
    'thursday'
  ],
  "In we go, out we go. All around and in a row. Always, always steady flow. When we'll stop, you'll never known. In we go, out we go.": [
    'tides'
  ],
  'There are two meanings to me. With one I may need to be broken, with the other I hold on. My favorite characteristic is my charming dimple.': [
    'tie'
  ],
  'Mountains will crumble and temples will fall. And no man can survive its endless call.': [
    'time'
  ],
  'This thing all things devours: Birds, beasts, trees, flowers; Gnaws iron, bites steel; Grinds hard stones to meal; Slays king, ruins town, And beats high mountains down.': [
    'time'
  ],
  'Until I am measured I am not known, Yet how you miss me when I have flown.': [
    'time'
  ],
  'What flies without wings? What passes all things? What mends all sorrow? What brings the morrow?': [
    'time'
  ],
  'What is it which builds things up? Lays mountains low? Dries up lakes, and makes things grow? Cares not a whim about your passing? And is like few other things, because it is everlasting?': [
    'time'
  ],
  'I never was, am always to be. No one ever saw me, nor ever will. And yet I am the confidence of all, To live and breath on this terrestrial ball. ': [
    'tomorrow'
  ],
  'Forward I’m heavy, but backwards I’m not. ': [
    'ton'
  ],
  'Often held but never touched. Always wet but never rusts. Often bits but seldom bit. To use it well you must have wit.': [
    'tongue'
  ],
  'Blend a teapot shot so the pearlies won’t rot!': [
    'toothpaste'
  ],
  'What gets wetter as it dries?': [
    'towel'
  ],
  'I saw a strange creature. Long, hard, and straight, thrusting into a round, dark opening. Preparing to discharge its load of lives. Puffing and squealing noises accompanied it, then a final screech as it slowed and stopped.': [
    'train'
  ],
  'Dies half its life. Lives the rest. Dances without music. Breathes without breath.': [
    'tree'
  ],
  "I am mother and father, but never birth or nurse. I'm rarely still, but I never wander.": [
    'tree'
  ],
  'Reaching stiffly for the sky, I bare my fingers when its cold. In warmth I wear an emerald glove and in between I dress in gold.': [
    'tree'
  ],
  'Some live in me, some live on. And some shave me to stride upon. I rarely leave my native land. Until my death I always stand. High and low I may be found. Both above and below ground.': [
    'tree'
  ],
  "Creatures of power, creatures of grade, creatures of beauty, creatures of strength. As for their lives, they set everything's pace. For all things must come to live. Under their emerald embrace\x85Either in their life or in their death.": [
    'trees'
  ],
  'Who is it that rows quickly with four oars, but never comes out from under his own roof?': [
    'turtle'
  ],
  'What goes up when the rain comes down?': [
    'umbrella'
  ],
  "My voice is tender, my waist is slender and I'm often invited to play. Yet wherever I go, I must take my bow or else I have nothing to say.": [
    'violin'
  ],
  'What instrument can make any sound and be heart, but not touched or seen?': [
    'voice'
  ],
  'My thunder comes before the lightning. My lightning comes before the clouds. My rain dries all the land it touches.': [
    'volcano'
  ],
  'We are five little objects of an everyday sort. You will find us all in a tennis court.': [
    'vowels'
  ],
  'I run around the city, but I never move.': [
    'wall'
  ],
  'As soft as silk, as white as milk, as bitter as gall, a thick green wall, and a green coat covers me all.': [
    'walnut'
  ],
  'A harvest sown and reaped on the same day in an unplowed field. Which increases without growing, remains whole though it is eaten within and without. Is useless and yet the staple of nations.': [
    'war'
  ],
  'It is a part of us, and then replaced. It escapes out bodies, to a better place. The world becomes its sizeable home. Its passions unrestraint, the planet it roams.': [
    'water'
  ],
  'Runs smoother than any rhyme, loves to fall but cannot climb!': [
    'water'
  ],
  'Three lives have I. Gentle enough to soothe the skin. Light enough to caress the sky. Hard enough to crack rocks.': [
    'water'
  ],
  'Bright as diamonds, Loud as thunder, Never still, A thing of wonder.': [
    'waterfall'
  ],
  'The moon is my father. The sea is my mother. I have a million brothers. I die when I reach land.': [
    'wave'
  ],
  'My first is in wield, sever bones and marrow. My second is in blade, forged in cold steel. My third is an arbalest, and also in arrows. My fourth is in power, plunged through a shield. My fifth is in honor, and also in vows. My last will put an end to it all.': [
    'weapon'
  ],
  "As round as an apple. As deep as a cup. All the king's horses can't pull it up.": [
    'well'
  ],
  'I go around in circles, but always straight ahead. Never complain, no matter where I am led.': [
    'wheel'
  ],
  "A leathery snake, with a stinging bite. I'll stay coiled up, unless I must fight.": [
    'whip'
  ],
  'All about, but cannot be seen, Can be captured, cannot be held, No throat, but can be heard.': [
    'wind'
  ],
  'I pass before the sun, but make no shadow. ': [
    'wind'
  ],
  'Voiceless it cries,Voiceless it cries, Wingless flutters, Toothless bites, Mouthless mutters.': [
    'wind'
  ],
  'What flies forever, Rests never?': [
    'wind'
  ],
  'I have four wings but cannot fly. I never laugh and never cry. On the same spot always found, toiling away with little sound.': [
    'windmill'
  ],
  'There is an ancient invention. Still used in some parts of the world today. That allows people to see through walls.': [
    'window'
  ],
  'When young, I am sweet in the sun. When middle-aged, I make you gay. When old, I am valued more than ever.': [
    'wine'
  ],
  'I am the heart that does not beat. If cut, I bleed without blood. I can fly, but have no wings. I can float, but have no fins. I can sing, but have no mouth.': [
    'wood'
  ],
  'What is it that you must give before you can keep it.': [
    'word'
  ],
  'What does no man want, yet no man want to lose?': [
    'work'
  ],
  'What must be in the oven yet can not be baked? Grows in the heat yet shuns the light of day? What sinks in water but rises with air? Looks like skin but is fine as hair?': [
    'yeast'
  ]
}


import random

def riddle_factory(data):
    """Factory function to create stateful get_riddle and get_riddles functions."""
    cache = []
    cache_index = 0

    def get_riddle():
        nonlocal cache, cache_index
        if cache_index < len(cache):
            riddle = cache[cache_index]
            cache_index += 1
            return riddle
        else:
            question, answers = random.choice(list(data.items()))
            riddle = {'question': question, 'answer': answers[0]}
            return riddle

    def get_riddles(count=1):
        nonlocal cache, cache_index
        if count > len(data):
            raise ValueError("Requested count exceeds available number of unique riddles.")

        if cache_index + count <= len(cache):
            riddles = cache[cache_index:cache_index + count]
            cache_index += count
            return riddles
        else:
            selected_items = random.sample(list(data.items()), k=min(2 * count, len(data)))
            cache[:] = [{'question': q, 'answer': a[0]} for q, a in selected_items]
            cache_index = 0
            return get_riddles(count)

    return get_riddle, get_riddles




import argparse
import random


from .riddle import riddle_factory
from .data import data

get_riddle, get_riddles = riddle_factory(data)

def create_argparser():
    parser = argparse.ArgumentParser(description="Fetch and display riddles.")
    parser.add_argument("-c", "--count", type=int, default=1, help="Number of riddles to retrieve, defaults to 1 if not provided.")
    return parser

def main():
    parser = create_argparser()
    args = parser.parse_args()

    try:
        # Check for positive count
        if args.count < 1:
            raise ValueError("Count must be at least 1.")

        if args.count == 1:
            riddle = get_riddle()
            print(f"Riddle: {riddle['question']}")
            print(f"Answer: {riddle['answer']}")
        else:
            riddles = get_riddles(args.count)
            for idx, r in enumerate(riddles, start=1):
                print(f"Riddle {idx}: {r['question']}")
                print(f"Answer: {r['answer']}")
                if idx < len(riddles):
                    print()

    except ValueError as ve:
        print(f"Error: {ve}")
    except Exception as e:
        print(f"An unexpected error occurred: {e}")

if __name__ == "__main__":
    main()



from setuptools import find_packages, setup

setup(
    name="pyriddle",
    version="1.0.0",
    description="A package that serves riddle(s).",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    long_description="Package to retrieve and display riddles",
    long_description_content_type="text/markdown",
    url="",
    author="mvsrsh",
    author_email="sriharsha.mangina@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
    ],
    install_requires=["bson >= 0.5.10"],
    extras_require={
        "dev": ["pytest>=7.0", "twine>=4.0.2"],
    },
    entry_points={
        "console_scripts": [
            "pyriddle=pyriddle.cli:main", 
        ],
    },
    python_requires=">=3.10",
)
